@@ -218,28 +218,14 @@ class dyn_obj:
         self.pa_axes.dynamic_6DOF(quat_list, None, None, None)
         self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list)
 
-    def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
-        """
-        Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
-
-        :param str staticity: a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
-        :param np.ndarray int_x: a numpy array of the x position over time
-        :param np.ndarray int_y: a numpy array of the y position over time
-        :param np.ndarray int_z: a numpy array of the z position over time
-        
-        """
-
-
+    def apply_streamline(self, staticity, int_x, int_y, int_z, frames, thickness):
         name = self.name+'_streamline'
-        """:type: `str`, the Blender object name of the streamline"""
-        frames = self.frames
-        """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
-        
+
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
-        int_coords[:, 0] = int_x*self.scale
-        int_coords[:, 1] = int_y*self.scale
-        int_coords[:, 2] = int_z*self.scale
+        int_coords[:, 0] = int_x
+        int_coords[:, 1] = int_y
+        int_coords[:, 2] = int_z
 
         int_curve = bpy.data.curves.new(name, type='CURVE')
         int_curve.dimensions = '3D'
@@ -257,20 +243,15 @@ class dyn_obj:
 
         # attach to scene and validate context
         bpy.context.collection.objects.link(int_curveOB)
-        
+
         int_curveOB.data.bevel_depth = thickness
-        int_curveOB.data.use_fill_caps = True
-
-
-        int_curveOB.data.bevel_factor_start = 0
-
-        curve_to_mesh(int_curveOB)
 
         if staticity == 'dynamic':
-            bpy.ops.object.modifier_add(type='BUILD')
-            bpy.context.object.modifiers["Build"].frame_start = 0
-            bpy.context.object.modifiers["Build"].frame_duration = self.frames[-1]+1
+            for i in range(len(frames)):
+                cur_frame = frames[i]
 
+                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]+1) * cur_frame
+                bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
 
 class dyn_vec:
     """
